@@ -2,16 +2,17 @@
 #ifndef __PREF_DICTGROUP_H__
 #define __PREF_DICTGROUP_H__
 
+#include "defs.h"
+
 void            dicts_show(GtkWidget *w, gpointer data);
 void            dicts_save();
 void            dicts_load();
-void            dicts_info(BOOK_INFO *binfo);
+GtkWidget*	dicts_info(gboolean create);
 BOOK_INFO*      dicts_find_binfo(EB_Book *book);
 GtkTreePath*    dicts_find_path(EB_Book *book);
 
 void            my_gtk_tree_store_swap(GtkTreeStore *tree_store, GtkTreeIter *a, GtkTreeIter *b);
 void            my_gtk_combo_box_set_active_text(GtkComboBox *combo, const gchar *text);
-typedef void    (*browse_callback)(gchar *);
 
 struct _dicts
 {
