@@ -18,7 +18,7 @@ enum
 struct _dump
 {
     gulong      handler[DUMP_N];
-    GtkWidget   *dlg[DUMP_N], *item[DUMP_N], *view[DUMP_N], *page[DUMP_N], *offset;
+    GtkWidget   *dlg[DUMP_N], *view[DUMP_N], *page[DUMP_N], *offset;
     GtkTextBuffer *buf[DUMP_N];
 } dump;
 
