@@ -4,14 +4,15 @@
 
 gint            ebook_search_method();
 BOOK_INFO*      ebook_load(const gchar *path, int subbook_no);
-GdkPixbuf*      ebook_load_image(EB_Book *book, EB_Position *pos);
+GdkPixbuf*      ebook_load_image(BOOK_INFO *binfo, EB_Position *pos);
 void            ebook_free(BOOK_INFO *binfo);
-gchar*          ebook_get_text(EB_Book *book, EB_Position *pos);
+gchar*          ebook_get_text(RESULT *res);
 gchar*          ebook_get_raw_text(EB_Book *book, gint page, gint offset);
 void            ebook_search(const gchar *word, gint method, GSequence *results, gint maxhits);
 void            ebook_search_book(const gchar *word, gint method, GSequence *results, gint maxhits, BOOK_INFO *binfo);
 void            ebook_menu_or_copyright(gboolean menu, GSequence *results);
-GdkPixbuf*      ebook_read_gaiji(EB_Book *book, gchar *code);
+GdkPixbuf*      ebook_read_gaiji(BOOK_INFO *binfo, gchar *code, gint *w, gint *h);
+EB_Error_Code	ebook_search_keyword(EB_Book *book, const char *input_word);
 
 enum
 {
