@@ -1,18 +1,19 @@
 
 #include "defs.h"
+#include "textview.h"
 
 void            mainwnd_show_about(GtkWidget *w, gpointer data);
 void            mainwnd_create();
-void            mainwnd_iconify();
+void            mainwnd_iconify_restore();
 void            mainwnd_open(RESULT *res);
-void            mainwnd_search(GtkWidget *w, gpointer data);
-void            mainwnd_search_word(const gchar *word);
+void            mainwnd_search(const gchar *word);
 void            mainwnd_reset_font();
+void            mainwnd_clear_combo();
 GtkWidget*      mainwnd_search_method_combo();
 
 struct _mainwnd
 {
-    gboolean    remember_pos;
+    gboolean    custom_font, remember_pos;
     gchar       *font;
     gint        x, y, w, h, search;
     GtkWidget   *wnd, *combo_method, *combo_word, *dictbar;
@@ -22,6 +23,7 @@ struct _mainwnd
 struct _paned
 {
     gint        treew, treeh;
-    GtkWidget   *pane, *tree, *text;
+    GtkWidget   *pane, *tree;
+    EbTextView	*view;
 } paned;
 
