@@ -3,18 +3,21 @@
 #define __POPUP_H__
 
 #include "defs.h"
+#include "textview.h"
 
 void            popupwnd_open(RESULT *res);
 void            popupwnd_close();
 void            popupwnd_search(const gchar *str);
+void		popupwnd_find();
+//void            popupwnd_dict_menu_create(gboolean newmenu);
 
 struct _popupwnd
 {
-    gboolean    lock;
-    gint        width, height, search_method, timeout, maxhits;
+    gboolean    lock, remember_pos;
+    gint        x, y, w, h, search_method, timeout, maxhits;
     gchar       *group, *dict;
-    GtkWidget   *wnd, *view, *label, *scan, *menu, *lockbtn;
-    GtkTextBuffer *buffer;
+    GtkWidget   *wnd, *label, *scan, *menu, *lockbtn;
+    EbTextView	*view;
     GSequence   *results;
     BOOK_INFO   *binfo;
 } popupwnd;
