@@ -18,8 +18,7 @@ void            pref_mainwnd_search_end(gboolean save);
 
 struct _pref_mainwnd
 {
-    gboolean    font_set;
-    GtkWidget   *font, *wndpos;
+    GtkWidget   *bfont, *font, *wndpos;
     GtkWidget   *colors[COLOR_N];
     GtkWidget   *hits_auto, *hits, *word_hist;
 } pref_mainwnd;
