@@ -12,7 +12,7 @@ void        pref_popupwnd_search_end(gboolean save);
 
 struct _pref_popupwnd
 {
-    GtkWidget *interval, *maxchar, *width, *height, *hits, *method;
+    GtkWidget *interval, *maxchar, *width, *height, *hits, *method, *remember_pos;
 } pref_popupwnd;
 
 #endif /* __PREF_SELECTION_H__ */
