@@ -6,13 +6,14 @@
 
 #define FILENAME_DICTIONARIES   "dictionaries.xml"
 #define FILENAME_PREFERENCES    "preferences.xml"
-#define FILENAME_SHORTCUTS      "shortcuts.xml"
+#define FILENAME_HOTKEYS	"hotkeys.xml"
 #define FILENAME_HISTORY        "history.xml"
 
 void            preferences_init();
 void            preferences_load();
 void            preferences_show();
 void            preferences_save();
+void		preferences_close_wnd();
 void            preferences_show_cb(GtkWidget *w, gpointer data);
 
 struct _pref
