@@ -4,16 +4,18 @@
 
 #include "defs.h"
 
-void            selection_received(GtkWidget *widget, GtkSelectionData *data);
 void            selection_toggled(GtkToggleButton *togglebutton, gpointer data);
-void            selection_search(const gchar *str);
 void            selection_lookup_start();
 void            selection_lookup_stop();
+void            selection_lookup_suspend();
+void            selection_lookup_resume();
+void		selection_search_in_mainwnd();
+void		selection_search_in_popupwnd();
 
 struct _selection
 {
-    gboolean    lookup;
-    glong       interval, minchar, maxchar;
+    gboolean    lookup_started, lookup_suspended;
+    glong       maxchar;
     guint       timeout_id;
 } selection;
 
